#[repr(u8)]pub enum TargetResValue {
Ok = 0,
Timeout = 1,
IdMissed = 2,
InvalidParam = 3,
InvalidState = 4,
OtherWrite = 5,
Unsupported = 6,
Full = 7,
}Expand description
The result value of the request.
Variants
Ok = 0
Succeeded.
Timeout = 1
The request timed out.
IdMissed = 2
The cube is out of the area of position id.
InvalidParam = 3
The given parameters were invalid.
InvalidState = 4
The state of the cube went invalid (e.g. powered off during movement).
OtherWrite = 5
The new request was written.
Unsupported = 6
The request was not supported.
Full = 7
The number of the pending requests exceeds the capacity.